
## c8ylp

```
Usage: c8ylp [OPTIONS] COMMAND [ARGS]...

  Cumulocity Remote Access Local Proxy

Options:
  -h, --help  Show this message and exit.

Commands:
  connect  Connect to a device via different protocols (i.e.
  login    Login and save token to an environment file
  plugin   Run a custom plugin (installed under ~/.c8ylp/plugins/)
  server   Start local proxy in server mode
  version  Show the c8ylp version number

```
